<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi_FI">
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/mainmenu.cpp" line="57"/>
        <source>Play</source>
        <translation>Pelaa</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="61"/>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="65"/>
        <source>Credits</source>
        <translation>Tekijät</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="69"/>
        <source>Quit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="77"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>At least OpenGL ES 2.0 is required!</source>
        <translation type="vanished">Vähintään OpenGL ES 2.0 vaaditaan!</translation>
    </message>
    <message>
        <source>Cannot start Dust Racing 2D</source>
        <translation type="vanished">Ei voida käynnistää Dust Racing 2D</translation>
    </message>
    <message>
        <source>At least OpenGL 3.0 is required!</source>
        <translation type="vanished">Vähintään OpenGL 3.0 vaaditaan!</translation>
    </message>
    <message>
        <source>At least OpenGL 2.1 is required!</source>
        <translation type="vanished">Vähintään OpenGL 2.1 vaaditaan!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="347"/>
        <source>The Time Trial has ended!</source>
        <translation>Aika-ajo päättyi!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="351"/>
        <source>The winner has finished!</source>
        <translation>Voittaja tuli maaliin!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="69"/>
        <source>New lap record!</source>
        <translation>Uusi kierrosennätys!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="76"/>
        <source>New race record!</source>
        <translation>Uusi kilpailuennätys!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="376"/>
        <source>Pit stop!</source>
        <translation>Varikkopysähdys!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="569"/>
        <source>A new best pos!</source>
        <translation>Uusi paras sijoitus!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="579"/>
        <source>A new track unlocked!</source>
        <translation>Uusi rata avattu!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="583"/>
        <source>Better luck next time..</source>
        <translation>Parempaa onnea ensi kerralla..</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="626"/>
        <source>You must stay on track!</source>
        <translation>Pysy radalla!</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="630"/>
        <source>Watch your tires!</source>
        <translation>Varo renkaitasi!</translation>
    </message>
    <message>
        <location filename="../startlights.cpp" line="135"/>
        <source>GO!!!</source>
        <translation>AJA!!!</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="52"/>
        <source>---</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="53"/>
        <source>1st</source>
        <translation>1.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="54"/>
        <source>2nd</source>
        <translation>2.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="55"/>
        <source>3rd</source>
        <translation>3.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="56"/>
        <source>4th</source>
        <translation>4.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="57"/>
        <source>5th</source>
        <translation>5.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="58"/>
        <source>6th</source>
        <translation>6.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="59"/>
        <source>7th</source>
        <translation>7.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="60"/>
        <source>8th</source>
        <translation>8.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="61"/>
        <source>9th</source>
        <translation>9.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="62"/>
        <source>10th</source>
        <translation>10.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="63"/>
        <source>11th</source>
        <translation>11.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="64"/>
        <source>12th</source>
        <translation>12.</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="185"/>
        <source> LAP:</source>
        <translation> KIER:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="202"/>
        <source> POS:</source>
        <extracomment>Position/rank</extracomment>
        <translation> SIJA:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="210"/>
        <source>LAP</source>
        <translation>KIER</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="210"/>
        <source>LAPS</source>
        <translation>KIER</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="247"/>
        <source> KM/H</source>
        <translation> KM/H</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="260"/>
        <source>LAP:</source>
        <translation>KIE:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="306"/>
        <source>L:</source>
        <extracomment>Last lap time</extracomment>
        <translation>V:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="326"/>
        <source>R:</source>
        <extracomment>Lap record time</extracomment>
        <translation>E:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="347"/>
        <source>TOT:</source>
        <extracomment>Total race time</extracomment>
        <translation>KOK:</translation>
    </message>
    <message>
        <location filename="../menu/help.cpp" line="31"/>
        <source>GAME GOAL

You are racing against eleven
computer players.

Your best position will be
the next start position.

Finish in TOP-6 to unlock
a new race track!

CONTROLS FOR PLAYER 1

Turn left  : Left
Turn right : Right
Accelerate : Up / RIGHT SHIFT
Brake      : Down / RIGHT CTRL

CONTROLS FOR PLAYER 2

Turn left  : A
Turn right : D
Accelerate : W / LEFT SHIFT
Brake      : S / LEFT CTRL

Quit       : ESC/Q
Pause      : P</source>
        <translation>PELIN TARKOITUS

Vastassasi on 11 autoa.

Seuraava lähtöruutusi on
paras sijasi.

Sijoittuminen TOP-6:een
avaa uuden radan!

KONTROLLIT PELAAJALLE 1

Vasemmalle : Vasen nuoli
Oikealle   : Oikea nuoli
Kaasuta    : Ylös / OIKEA SHIFT
Jarruta    : Alas / OIKEA CTRL

KONTROLLIT PELAAJALLE 2

Vasemmalle : A
Oikealle   : D
Kaasuta    : W / VASEN SHIFT
Jarruta    : S / VASEN CTRL

Poistu     : ESC/Q
Pause      : P</translation>
    </message>
    <message>
        <source>PROGRAMMING BY

* Jussi Lind

GRAPHICS BY

* Jussi Lind
* Ville Makiranta
* FindIcons.com

RACE TRACKS BY

* Jussi Lind

FONT

* Ubuntu Monospace

PATCHES

* Markus Rinne

SPECIAL THANKS

* Tommi Martela</source>
        <translation type="obsolete">OHJELMOINTI

* Jussi Lind

GRAFIIKKA

* Jussi Lind
* Ville Makiranta
* FindIcons.com

RADAT

* Jussi Lind

FONTTI

* Ubuntu Monospace

PÄTSIT

* Markus Rinne

ERITYISKIITOKSET

* Tommi Martela</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="78"/>
        <source>Reset best positions?</source>
        <translation>Nollaa parhaat sijat?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="89"/>
        <source>Reset record times?</source>
        <translation>Nollaa ennätysajat?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="101"/>
        <source>Reset unlocked tracks?</source>
        <translation>Nollaa lukitsemattomat radat?</translation>
    </message>
    <message>
        <source>Difficulty &gt;</source>
        <translation type="vanished">Vaikeustaso &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="204"/>
        <source>Sounds &gt;</source>
        <translation>Äänet &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="208"/>
        <source>GFX &gt;</source>
        <translation>Grafiikka &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="216"/>
        <source>Reset &gt;</source>
        <translation>Nollaus &gt;</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="42"/>
        <source>Easy</source>
        <translation>Helppo</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="52"/>
        <source>Medium</source>
        <translation>Keskitaso</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="62"/>
        <source>Hard</source>
        <translation>Vaikea</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="374"/>
        <source>VSync &gt;</source>
        <translation>VSync &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="435"/>
        <source>Reset record times</source>
        <translation>Nollaa ennätysajat</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="439"/>
        <source>Reset best positions</source>
        <translation>Nollaa parhaat sijat</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="443"/>
        <source>Reset unlocked tracks</source>
        <translation>Nollaa lukitsemattomat radat</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="358"/>
        <source>Full screen resolution &gt;</source>
        <translation>Koko näytön resoluutio &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="362"/>
        <source>Windowed resolution &gt;</source>
        <translation>Ikkunoitu resoluutio &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="366"/>
        <source>FPS &gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="370"/>
        <source>Split type &gt;</source>
        <translation>Ruudunjaon tyyppi &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="200"/>
        <source>Game mode &gt;</source>
        <translation>Pelimoodi &gt; </translation>
    </message>
    <message>
        <source>Lap Count &gt;</source>
        <translation type="vanished">Kierrosmäärä &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="212"/>
        <source>Controls &gt;</source>
        <translation>Kontrollit &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="277"/>
        <source>Two player race</source>
        <translation>Kahden pelaajan kisa</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="286"/>
        <source>One player race</source>
        <translation>Yhden pelaajan kisa</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="295"/>
        <source>Time Trial</source>
        <translation>Aika-ajo</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="304"/>
        <source>Duel</source>
        <translation>Kaksintaistelu</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="328"/>
        <source>Vertical</source>
        <translation>Pysty</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="337"/>
        <source>Horizontal</source>
        <translation>Vaaka</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="236"/>
        <source>30 fps</source>
        <translation>30 ruutua/s</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="246"/>
        <source>60 fps</source>
        <translation>60 ruutua/s</translation>
    </message>
    <message>
        <source>  Laps: </source>
        <translation type="obsolete">   Kierroksia: </translation>
    </message>
    <message>
        <source>Length: </source>
        <translation type="obsolete">       Pituus: </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="266"/>
        <source>       Laps: </source>
        <translation>     Kierrokset:</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="273"/>
        <source>     Length: </source>
        <translation>         Pituus:</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="311"/>
        <source>Finish previous track in TOP-6 to unlock!</source>
        <extracomment>Try to keep the translation as short as possible.</extracomment>
        <translation>Avaa sijoittumalla TOP-6:een edellisessä radassa!</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="316"/>
        <source>Unlock it in one/two player race!</source>
        <extracomment>&quot;it&quot; = a locked track. Try to keep the translation as short as possible.</extracomment>
        <translation>Avaa yksin-/kaksinpelissä!</translation>
    </message>
    <message>
        <source> m</source>
        <translation type="vanished"> m</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="280"/>
        <source> Lap Record: </source>
        <translation> Kierrosennätys:</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="287"/>
        <source>Race Record: </source>
        <translation>Kilpailuennätys:</translation>
    </message>
    <message>
        <source>Record: </source>
        <translation type="obsolete">      Ennätys: </translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="49"/>
        <source>Press a key..</source>
        <translation>Paina näppäintä..</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="89"/>
        <source>Player One Accelerate</source>
        <translation>Pelaaja 1 Kaasu</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="98"/>
        <source>Player One Brake</source>
        <translation>Pelaaja 1 Jarru</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="107"/>
        <source>Player One Turn Left</source>
        <translation>Pelaaja 1 Vasemmalle</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="116"/>
        <source>Player One Turn Right</source>
        <translation>Pelaaja 1 Oikealle</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="138"/>
        <source>Player Two Accelerate</source>
        <translation>Pelaaja 2 Kaasu</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="147"/>
        <source>Player Two Brake</source>
        <translation>Pelaaja 2 Jarru</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="156"/>
        <source>Player Two Turn Left</source>
        <translation>Pelaaja 2 Vasemmalle</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="165"/>
        <source>Player Two Turn Right</source>
        <translation>Pelaaja 2 Oikealle</translation>
    </message>
    <message>
        <source>PROGRAMMING BY

</source>
        <translation type="obsolete">OHJELMOINTI\n</translation>
    </message>
    <message>
        <source>GRAPHICS BY

</source>
        <translation type="obsolete">GRAFIIKKA</translation>
    </message>
    <message>
        <source>RACE TRACKS BY

</source>
        <translation type="obsolete">RADAT</translation>
    </message>
    <message>
        <source>FONT

</source>
        <translation type="obsolete">FONTTI</translation>
    </message>
    <message>
        <source>PATCHES

</source>
        <translation type="obsolete">PÄTSIT</translation>
    </message>
    <message>
        <source>SPECIAL THANKS

</source>
        <translation type="obsolete">ERITYISKIITOKSET</translation>
    </message>
    <message>
        <source>PROGRAMMING BY</source>
        <translation type="vanished">OHJELMOINTI</translation>
    </message>
    <message>
        <source>GRAPHICS BY</source>
        <translation type="vanished">GRAFIIKKA</translation>
    </message>
    <message>
        <source>RACE TRACKS BY</source>
        <translation type="vanished">RADAT</translation>
    </message>
    <message>
        <source>CONTRIBUTORS</source>
        <translation type="vanished">AVUSTAJAT</translation>
    </message>
    <message>
        <source>FONT</source>
        <translation type="obsolete">FONTTI</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="40"/>
        <source>PROGRAMMING</source>
        <translation>OHJELMOINTI</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="42"/>
        <source>GRAPHICS</source>
        <translation>GRAFIIKKA</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="44"/>
        <source>LEVEL DESIGN</source>
        <translation>RADAT</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="46"/>
        <source>TRANSLATIONS</source>
        <translation>KÄÄNNÖKSET</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="48"/>
        <source>PATCHES</source>
        <translation>PÄTSIT</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="50"/>
        <source>SPECIAL THANKS</source>
        <translation>ERITYISKIITOKSET</translation>
    </message>
    <message>
        <location filename="../menu/resolutionmenu.cpp" line="115"/>
        <source>Restart to change the resolution.</source>
        <translation>Uudelleenkäynnistys vaaditaan.</translation>
    </message>
    <message>
        <source>Native resolution</source>
        <translation type="vanished">Natiiviresoluutio</translation>
    </message>
    <message>
        <location filename="../menu/confirmationmenu.cpp" line="31"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../menu/confirmationmenu.cpp" line="32"/>
        <source>Cancel</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <location filename="../menu/vsyncmenu.cpp" line="75"/>
        <source>Restart to change VSync setting.</source>
        <translation>Uudelleenkäynnistys vaaditaan.</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="393"/>
        <location filename="../menu/vsyncmenu.cpp" line="99"/>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="405"/>
        <location filename="../menu/vsyncmenu.cpp" line="103"/>
        <source>On</source>
        <translation>Päälle</translation>
    </message>
    <message>
        <location filename="../menu/lapcountmenu.cpp" line="84"/>
        <source>Choose lap count</source>
        <translation>Valitse kierrosmäärä</translation>
    </message>
</context>
</TS>
